@@ -25,7 +25,7 @@ class Token():
         self.parent_model = parent_model
 
     def enable(self, enable):
-        request(self.parent_model.address, '/coreDav/webdav/enable/', {'login': self.parent_model.login,
+        request(self.parent_model.oc_address, '/coreDav/webdav/enable/', {'login': self.parent_model.login,
                                            'pw_hash': calc_hash(self.parent_model.password, self.parent_model.seed),
                                            'token_id': self.parent_model.id,
                                            'enable': enable})
