@@ -17,18 +17,19 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-
+import pyCore.extensions.vpn.models.vpn
 from pyCore.utils import request, calc_hash
 
 class Api():
     def __init__(self, parent_model):
         self.parent_model = parent_model
 
-    def get_list(self, enable):
-        resp = request(self.parent_model.address, '/vpn/network/get_list/', {'token': self.parent_model.token})
+    def get_list(self):
+        resp = request(self.parent_model.oc_address, '/vpn/network/get_list/', {'token': self.parent_model.token})
+        return [pyCore.extensions.vpn.models.vpn.VPN(self.parent_model.oc_address, self.parent_model.token, vpn) for vpn in resp]
 
     def create(self, address, mask):
-        resp = request(self.parent_model.address, '/vpn/network/create/', {'token': self.parent_model.token,
+        resp = request(self.parent_model.oc_address, '/vpn/network/create/', {'token': self.parent_model.token,
                                                                            'mask': mask,
                                                                            'address': address})
-        return pyCore.extensions.models.vpn.VPN(self.parent_model.oc_address, self.parent_model.token, resp)
\ No newline at end of file
+        return pyCore.extensions.vpn.models.vpn.VPN(self.parent_model.oc_address, self.parent_model.token, resp)
\ No newline at end of file
